<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => 'F25522',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/daksha-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'daksha_customize_register' ) ) {
	add_action( 'customize_register', 'daksha_customize_register' );
	function daksha_customize_register( $wp_customize ) {
				
		// Add Daksha customizer section
		$wp_customize->add_section(
			'daksha_layout_effects',
			array(
				'title' => __( 'Daksha Effects', 'daksha' ),
				'priority' => 24,
			)
		);
		
		
		// Unique fixed side content
		$wp_customize->add_setting(
			'daksha_settings[fixed_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'daksha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'daksha_settings[fixed_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Unique fixed side content', 'daksha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'daksha' ),
					'disable' => __( 'Disable', 'daksha' )
				),
				'settings' => 'daksha_settings[fixed_effect]',
				'section' => 'daksha_layout_effects',
				'priority' => 1
			)
		);
		
		// Cursor
		$wp_customize->add_setting(
			'daksha_settings[cursor]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'daksha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'daksha_settings[cursor]',
			array(
				'type' => 'select',
				'label' => __( 'Cursor', 'daksha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'daksha' ),
					'disable' => __( 'Disable', 'daksha' )
				),
				'settings' => 'daksha_settings[cursor]',
				'section' => 'daksha_layout_effects',
				'priority' => 3
			)
		);
		
		// Blog posts border
		$wp_customize->add_setting(
			'daksha_settings[blog_posts_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'daksha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'daksha_settings[blog_posts_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Blog posts border', 'daksha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'daksha' ),
					'disable' => __( 'Disable', 'daksha' )
				),
				'settings' => 'daksha_settings[blog_posts_effect]',
				'section' => 'daksha_layout_effects',
				'priority' => 2
			)
		);
		
		// Nicescroll
		$wp_customize->add_setting(
			'daksha_settings[nicescroll]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'daksha_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'daksha_settings[nicescroll]',
			array(
				'type' => 'select',
				'label' => __( 'Daksha scrollbar style', 'daksha' ),
				'choices' => array(
					'enable' => __( 'Enable', 'daksha' ),
					'disable' => __( 'Disable', 'daksha' )
				),
				'settings' => 'daksha_settings[nicescroll]',
				'section' => 'daksha_layout_effects',
				'priority' => 8
			)
		);
		
	}
}

//Sanitize choices.
if ( ! function_exists( 'daksha_sanitize_choices' ) ) {
	function daksha_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Daksha effects colors css
if ( ! function_exists( 'daksha_effect_colors_css' ) ) {
	function daksha_effect_colors_css() {
		// Get our settings from parent theme
		$lalita_settings = wp_parse_args(
			get_option( 'lalita_settings', array() ),
			lalita_get_color_defaults()
		);
		
		$daksha_extracolors = '.daksha-fixed-effect .lalita-side-left-content .lalita-side-left-socials ul,.daksha-fixed-effect .lalita-side-left-content .lalita-side-left-text, .daksha-fixed-effect .lalita-side-left-content .lalita-socials-list li a {color: ' . esc_attr( $lalita_settings[ 'fixed_side_content_background_color' ] ) . ';}.daksha-fixed-effect .lalita-side-left-content .lalita-socials-list li, .daksha-fixed-effect .lalita-side-left-content .lalita-side-left-text {border-color: ' . esc_attr( $lalita_settings[ 'fixed_side_content_background_color' ] ) . ';}.daksha-fixed-effect .lalita-side-left-content .lalita-socials-list li:hover {background: ' . esc_attr( $lalita_settings[ 'fixed_side_content_background_color' ] ) . ';}.daksha-fixed-effect .lalita-side-left-content .lalita-socials-list li:hover a{color: ' . esc_attr( $lalita_settings[ 'fixed_side_content_text_color' ] ) . ';}';
		
		return $daksha_extracolors;
	}
}


// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'daksha_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'daksha_remove_parent_dynamic_css' );
	function daksha_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'daksha_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'daksha_enqueue_parent_dynamic_css', 50 );
	function daksha_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .daksha_effect_colors_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'daksha_body_classes' ) ) {
	add_filter( 'body_class', 'daksha_body_classes' );
	function daksha_body_classes( $classes ) {
		// Get Customizer settings
		$daksha_settings = get_option( 'daksha_settings' );
		
		$fixed_effect 	   = 'enable';
		$blog_posts_effect = 'enable';
		$cursor  	   	   = 'enable';
		$nicescroll  	   = 'enable';
		
		if ( isset( $daksha_settings['fixed_effect'] ) ) {
			$fixed_effect = $daksha_settings['fixed_effect'];
		}
		
		if ( isset( $daksha_settings['blog_posts_effect'] ) ) {
			$blog_posts_effect = $daksha_settings['blog_posts_effect'];
		}
		
		if ( isset( $daksha_settings['cursor'] ) ) {
			$cursor = $daksha_settings['cursor'];
		}
		
		if ( isset( $daksha_settings['nicescroll'] ) ) {
			$nicescroll = $daksha_settings['nicescroll'];
		}
		
		// Unique fixed side content
		if ( $fixed_effect != 'disable' ) {
			$classes[] = 'daksha-fixed-effect';
		}
		
		// Blog posts border
		if ( $blog_posts_effect != 'disable' ) {
			$classes[] = 'daksha-blog-title-effect';
		}
		
		// Cursor
		if ( $cursor != 'disable' ) {
			$classes[] = 'daksha-cursor-style';
		}
		
		// Scrollbar style function
		if ( $nicescroll != 'disable' ) {
			$classes[] = 'daksha-scrollbar-style';
		}
		
		return $classes;
	}
}

if ( ! function_exists( 'daksha_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'daksha_scripts' );
	/**
	 * Enqueue script
	 */
	function daksha_scripts() {
		
		$daksha_settings = get_option( 'daksha_settings' );
		
		$cursor		 = 'enable';
		if ( isset( $daksha_settings['cursor'] ) ) {
			$cursor = $daksha_settings['cursor'];
		}
		
		if ( $cursor != 'disable' ) {
			wp_enqueue_style( 'daksha-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/css/magic-mouse.min.css", false, LALITA_VERSION, 'all' );
			wp_enqueue_script( 'daksha-magic-mouse', esc_url( get_stylesheet_directory_uri() ) . "/js/magic-mouse.min.js", array( 'jquery'), LALITA_VERSION, true );
		}
		
	}
}